@@ -6,6 +6,8 @@ use serde_derive::Deserialize;
 use std::{collections::HashMap, fmt, fmt::Formatter, fs::read_to_string, process::Command};
 use toml::from_str;
 
+const SLASH: &str = if cfg!(windows) { "\\" } else { "/" };
+
 #[derive(Deserialize, Debug)]
 struct Workspace {
     members: Vec<String>,
@@ -73,7 +75,7 @@ fn main() {
         .members
         .iter()
         .map(|member| {
-            let cargo_toml_file = String::from(".\\") + &member + "\\Cargo.toml";
+            let cargo_toml_file = String::from(".") + SLASH + &member + SLASH + "Cargo.toml";
             let cargo_toml_str = read_to_string(cargo_toml_file).unwrap();
             let cargo_toml: CargoToml = from_str(&cargo_toml_str).unwrap();
             (member.clone(), cargo_toml)
@@ -118,25 +120,25 @@ fn main() {
             let line = String::from_utf8(x.stdout)
                 .unwrap()
                 .lines()
-                .nth(0)
+                .next()
                 .unwrap()
                 .to_string();
             let x: HashMap<String, String> = from_str(&line).unwrap();
-            let i = x.iter().nth(0).unwrap();
+            let i = x.iter().next().unwrap();
             println!("crates.io: {} = {}", i.0, i.1);
             i.1.clone()
         };
-        if crate_version != member.1.package.version
-        {
+        if crate_version != member.1.package.version {
             // TODO:
             // 1. check if a package is available after uploading using `cargo search`.
-            // 2. check if a package version is already uploaded.
+            // 2. check if package dependencies are updated then the package should have a new version.
+            // 3. check if the package is changed (using Git and a commit id from crates.io) (we need to include a commit id into package metadata)
             //
             // Note:
             // don't use `canonicalize`. `canonicalize` returns a UNC path.
             // https://github.com/rust-lang/rust/issues/42869
             // `cargo` can't handle properly UNC paths.
-            let p = String::from(".\\") + &key;
+            let p = String::from(".") + SLASH + &key;
             let _ = Command::new("cargo")
                 .arg("publish")
                 .current_dir(p)
